@@ -17,4 +17,12 @@ test_that("the connected components algorithm works", {
     diamondKernel <- shapeKernel(c(3,3), type="diamond")
     expect_that(components(data,boxKernel), equals_reference("fan_components_box.rds"))
     expect_that(components(data,diamondKernel), equals_reference("fan_components_diamond.rds"))
+    
+    # 0 1 1
+    # 0 0 0
+    # 0 1 1
+    # Make sure there is no inappropriate wrap-around
+    data <- matrix(c(0,0,0,1,0,1,1,0,1), 3, 3)
+    result <- components(data, shapeKernel(c(3,3)))
+    expect_that(result[1,3] == result[3,3], is_false())
 })
